"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.stopServer = exports.startServer = void 0;
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const kill_port_1 = tslib_1.__importDefault(require("kill-port"));
const koa_1 = tslib_1.__importDefault(require("koa"));
const client_1 = require("@/client");
const socket_server_1 = require("@/socket-server");
const log_1 = require("@/utils/log");
const db_1 = require("@/db");
const router_1 = require("@/router");
const config_1 = require("@/config");
const import_addon_1 = require("@/child-process/import-addon");
const log = new log_1.Logger('app-debug-server');
let server;
let socketServer;
/**
 * 开启调试服务
 */
const startServer = () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    log.info('start server argv: %j', global.debugAppArgv);
    yield init();
    const { host, port, isRemote } = global.debugAppArgv;
    const app = new koa_1.default();
    router_1.routeApp(app);
    server = app.listen(port, host, () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        log.info('start debug server success.');
        let startAdbProxy;
        if (!isRemote) {
            const childProcesFn = yield Promise.resolve().then(() => tslib_1.__importStar(require('./child-process/index')));
            const { startTunnel, startChrome } = childProcesFn;
            startAdbProxy = childProcesFn.startAdbProxy;
            startTunnel();
            startAdbProxy();
            startChrome();
        }
        socketServer = new socket_server_1.SocketServer(server);
        socketServer.start();
    }));
    server.on('close', () => {
        log.warn('debug server is closed.');
    });
});
exports.startServer = startServer;
/**
 * 停止调试服务
 */
const stopServer = (exitProcess = false, ...arg) => {
    var _a;
    try {
        log.info('stopServer %j', arg);
        if (server) {
            server.close();
            server = null;
        }
        if (exitProcess)
            process.exit(0);
    }
    catch (e) {
        log.error('stopServer error, %s', (_a = e) === null || _a === void 0 ? void 0 : _a.stack);
    }
};
exports.stopServer = stopServer;
/**
 * 服务初始化
 */
const init = () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    var _a, _b;
    const { cachePath } = config_1.config;
    try {
        fs_1.default.rmdirSync(cachePath, { recursive: true });
    }
    catch (e) {
        log.error('rm cache dir error: %s', (_a = e) === null || _a === void 0 ? void 0 : _a.stack);
    }
    yield import_addon_1.importTunnel();
    yield fs_1.default.promises.mkdir(cachePath, { recursive: true });
    yield db_1.initDbModel();
    client_1.initAppClient();
    const { port, iWDPPort, clearAddrInUse } = global.debugAppArgv;
    if (clearAddrInUse) {
        try {
            yield kill_port_1.default(port, 'tcp');
            yield kill_port_1.default(iWDPPort, 'tcp');
        }
        catch (e) {
            log.error('Address %s %s already in use! %s', port, iWDPPort, (_b = e) === null || _b === void 0 ? void 0 : _b.stack);
            return process.exit(1);
        }
    }
});
