"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IWDPAppClient = void 0;
const tslib_1 = require("tslib");
const ws_1 = tslib_1.__importDefault(require("ws"));
const log_1 = require("@/utils/log");
const app_client_1 = require("./app-client");
const log = new log_1.Logger('app-client:IWDP');
/**
 * IWDP 调试通道，通过 ws client 与 IWDP server 建立连接
 */
class IWDPAppClient extends app_client_1.AppClient {
    constructor(id, option) {
        super(id, option);
        this.requestPromiseMap = new Map();
        this.msgBuffer = [];
        this.url = option.iWDPWsUrl;
        if (!this.url) {
            const e = new Error('IWDPAppClient constructor option need iWDPWsUrl, if you are debug iOS without USB, please ignore this error.');
            throw e;
        }
        this.type = "IWDPAppClient" /* IWDP */;
        this.connect();
    }
    registerMessageListener() {
        if (!this.ws)
            return;
        this.ws.on('message', (msg) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            let msgObj;
            try {
                msgObj = JSON.parse(msg);
            }
            catch (e) {
                log.error(`parse json error: ${msg}`);
            }
            const res = yield this.downwardMessageHandler(msgObj);
            if (!('id' in msgObj))
                return;
            const requestPromise = this.requestPromiseMap.get(msgObj.id);
            if (requestPromise) {
                requestPromise.resolve(res);
            }
        }));
        this.ws.on('open', () => {
            log.info(`ios proxy client opened: ${this.url}`);
            for (const { msg, resolve, reject } of this.msgBuffer) {
                const msgStr = JSON.stringify(msg);
                this.ws.send(msgStr);
                this.requestPromiseMap.set(msg.id, { resolve, reject });
            }
            this.msgBuffer = [];
        });
        this.ws.on('close', () => {
            this.isClosed = true;
            this.emit("close" /* Close */);
            const e = new Error('ws closed');
            for (const requestPromise of this.requestPromiseMap.values()) {
                requestPromise.reject(e);
            }
        });
        this.ws.on('error', (e) => {
            log.error('ios proxy client error: %s', e === null || e === void 0 ? void 0 : e.stack);
        });
    }
    sendHandler(msg) {
        return new Promise((resolve, reject) => {
            var _a;
            if (((_a = this.ws) === null || _a === void 0 ? void 0 : _a.readyState) === ws_1.default.OPEN) {
                const msgStr = JSON.stringify(msg);
                this.ws.send(msgStr);
                this.requestPromiseMap.set(msg.id, { resolve, reject });
            }
            else {
                this.msgBuffer.push({
                    msg,
                    resolve,
                    reject,
                });
            }
        });
    }
    /**
     * 与 IWDP server 建立连接
     */
    connect() {
        var _a, _b, _c;
        if (((_a = this.ws) === null || _a === void 0 ? void 0 : _a.readyState) === ws_1.default.OPEN || ((_b = this.ws) === null || _b === void 0 ? void 0 : _b.readyState) === ws_1.default.CONNECTING)
            return;
        try {
            this.ws = new ws_1.default(this.url);
            this.registerMessageListener();
        }
        catch (e) {
            log.error('IWDP connect error: %s', (_c = e) === null || _c === void 0 ? void 0 : _c.stack);
            throw e;
        }
    }
}
exports.IWDPAppClient = IWDPAppClient;
