"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initDbModel = exports.getDBOperator = void 0;
const tslib_1 = require("tslib");
const enum_1 = require("@/@types/enum");
const model_1 = require("./memory/model");
const pub_sub_1 = require("./memory/pub-sub");
const model_2 = require("./redis/model");
const pub_sub_2 = require("./redis/pub-sub");
let model;
let Publisher;
let Subscriber;
/**
 * 获取数据库 model, Publisher, Subscriber
 */
const getDBOperator = () => ({
    model,
    Publisher,
    Subscriber,
});
exports.getDBOperator = getDBOperator;
/**
 * 初始化数据库环境
 */
const initDbModel = () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const { dbType } = global.debugAppArgv;
    if (dbType === enum_1.DBType.Memory) {
        model = new model_1.MemoryModel();
        Publisher = pub_sub_1.MemoryPubSub;
        Subscriber = pub_sub_1.MemoryPubSub;
    }
    if (dbType === enum_1.DBType.Redis) {
        model = new model_2.RedisModel();
        Publisher = pub_sub_2.RedisPublisher;
        Subscriber = pub_sub_2.RedisSubscriber;
    }
    yield model.init();
    return model;
});
exports.initDbModel = initDbModel;
